<?php
/**
 * Entego Kurulum Aşamaları Class
 *
 * Yeni kullanıcıları eklentiyi kurmak için bazı temel adımlar atmaktadır.
 *
 * @package     Entego-N11/Admin
 * @version     1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Entego_N11_Setup_Wizard class.
 */
class Entego_N11_Setup_Wizard {

	/**
	 * Mevcut adım
	 *
	 * @var string
	 */
	private $step = '';

	/**
	 * Kurulum sihirbazı için adımlar
	 *
	 * @var array
	 */
	private $steps = array();

	/**
	 * HTTP yanıtı tamamlandıktan sonra gerçekleştirilecek eylemler
	 *
	 * @var array
	 */
	private $deferred_actions = array();

	/**
	 * Tırnaklara asın.
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menus' ) );
		add_action( 'admin_init', array( $this, 'setup_wizard' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	

	/**
	 * Yönetici menüleri / ekranları ekleyin.
	 */
	public function admin_menus() {
		add_dashboard_page( '', '', 'manage_options', 'entego-n11-kurulum', '' );
	}

	/**
	 * Kurulum Sihirbazı için komut dosyalarını ve stilleri kaydedin / enqueue.
	 *
	 * 'Admin_enqueue_scripts'e bağlandı.	 
	 */
	public function enqueue_scripts() {
		$suffix          = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_register_script( 'jquery-blockui', ENTN11()->plugin_url() . '/admin/js/jquery-blockui/jquery.blockUI' . $suffix . '.js', array( 'jquery' ), '2.70', true );
		//wp_register_script( 'selectWoo', ENTN11()->plugin_url() . '/admin/js/selectWoo/selectWoo.full' . $suffix . '.js', array( 'jquery' ), '1.0.6' );
		wp_register_script( 'wc-enhanced-select', ENTN11()->plugin_url() . '/admin/js/admin/entego-n11-select' . $suffix . '.js', array( 'jquery', 'selectWoo' ), ENTEGO_N11_VERSION );
		wp_localize_script(
			'wc-enhanced-select',
			'wc_enhanced_select_params',
			array(
				'i18n_no_matches'           => _x( 'Hiç bir sonuç bulunamadı', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_ajax_error'           => _x( 'Yüklenirken bir sorun oluştu.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_short_1'    => _x( 'En az 1 karakter girmelisiniz.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_short_n'    => _x( 'Lütfen en az %qty% karakter yazınız', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_long_1'     => _x( 'Çok fazla karakter var 1 karakter silmelisiniz.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_long_n'     => _x( 'PLütfen en az %qty% karakter siliniz', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_selection_too_long_1' => _x( 'Bir seçim yapmalısınız', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_selection_too_long_n' => _x( 'En az %qty% seçim yapabilirsiniz.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_load_more'            => _x( 'Sonuçlar yükleniyor&hellip;', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_searching'            => _x( 'Aranıyor', 'gelişmiş seçim', 'entego-n11' ),
				'ajax_url'                  => admin_url( 'admin-ajax.php' ),
				'search_products_nonce'     => wp_create_nonce( 'search-products' ),
				'search_customers_nonce'    => wp_create_nonce( 'search-customers' ),
			)
		);
		wp_enqueue_style( 'woocommerce_admin_styles', ENTN11()->plugin_url() . '/admin/css/admin.css', array(), ENTEGO_N11_VERSION );
		wp_enqueue_style( 'entego-n11-setup', ENTN11()->plugin_url() . '/admin/css/entego-n11-setup.css', array( 'dashicons', 'install' ), ENTEGO_N11_VERSION );

		wp_register_script( 'entego-n11-setup', ENTN11()->plugin_url() . '/admin/js/admin/entego-n11-setup' . $suffix . '.js', array( 'jquery', 'wc-enhanced-select', 'jquery-blockui', 'wp-util', 'jquery-tiptip', 'backbone', 'wc-backbone-modal' ), ENTEGO_N11_VERSION );
		wp_localize_script(
			'entego-n11-setup',
			'wc_setup_params',
			array(
				'current_step'            => isset( $this->steps[ $this->step ] ) ? $this->step : false,
				'i18n'                    => array(
					'extra_plugins' => array(
						'sablon_secimi' => array(
							'stripe_create_account'        => __( 'Stripe setup is powered by Jetpack and WooCommerce Services.', 'woocommerce' ),
							'ppec_paypal_reroute_requests' => __( 'PayPal setup is powered by Jetpack and WooCommerce Services.', 'woocommerce' ),
							'stripe_create_account,ppec_paypal_reroute_requests' => __( 'Stripe and PayPal setup are powered by Jetpack and WooCommerce Services.', 'woocommerce' ),
						),
					),
				),
				'entego_kategori_nonce'=>wp_create_nonce('title_example'),
				'ajax_url'             => admin_url( 'admin-ajax.php' ),
				'entego_urun_bilgileri'=>wp_create_nonce('urun_bilgileri_getir'),
				'urunBilgileriHata'	=>_x('Bilinmeyen bir hata oluştu, lütfen daha sonra tekrar deneyiniz','entego-n11'),
			)
		);
	}

	/**
	 * Kurulum sihirbazını gösterin.
	 */
	public function setup_wizard() {
		if ( empty( $_GET['page'] ) || 'entego-n11-kurulum' !== $_GET['page'] ) {
			return;
		}
		$default_steps = array(
			'karsilama' => array(
				'name'       => '',
				'view'       => array( $this, 'entego_n11_setup_karsilama' ),
				'handler'    => array( $this, 'entego_n11_setup_karsilama_save' ),
			),
			'n11_anahtarlar'    => array(
				'name'       => __( 'N11 Anahtarlar', 'entego-n11' ),
				'view'       => array( $this, 'entego_n11_setup_anahtarlar' ),
				'handler'    => array( $this, 'entego_n11_setup_anahtarlar_save' ),
			),
			'sablon_secimi'        => array(
				'name'       => __( 'Şablon Seçimi', 'entego-n11' ),
				'view'       => array( $this, 'entego_n11_setup_sablon' ),
				'handler'    => array( $this, 'entego_n11_setup_sablon_save' ),
			),
			'bilgiler'    => array(
				'name'       => __( 'Önemli Bilgiler', 'entego-n11' ),
				'view'       => array( $this, 'entego_n11_setup_bilgiler' ),
				'handler'    => array( $this, 'entego_n11_setup_bilgiler_save' ),
			),
			'final'     => array(
				'name'       => __( 'Hazır!', 'entego-n11' ),
				'view'       => array( $this, 'entego_n11_setup_hazir' ),
				'handler'    => '',
			),
		);


		$this->steps = $default_steps;
		$this->step  = isset( $_GET['step'] ) ? sanitize_key( sanitize_text_field($_GET['step']) ) : current( array_keys( $this->steps ) );

		if ( ! empty( sanitize_text_field($_POST['save_step']) ) && isset( $this->steps[ $this->step ]['handler'] ) ) {
			call_user_func( $this->steps[ $this->step ]['handler'], $this );
		}

		ob_start();
		$this->setup_wizard_header();
		$this->setup_wizard_steps();
		$this->setup_wizard_content();
		$this->setup_wizard_footer();
		exit;
	}

	/**
	 * Bir sonraki adımın ekranının URL'sini alın.
	 *
	 * @param string $ step slug (varsayılan: geçerli adım).
	 * Bir sonraki adım varsa, bir sonraki adım için dize URL'sini döndürür.
	 * Son adım ise Yönetici URL'si.
	 * Hata durumunda boş dize.	 * @since 3.0.0
	 */
	public function get_next_step_link( $step = '' ) {
		if ( ! $step ) {
			$step = $this->step;
		}

		$keys = array_keys( $this->steps );
		if ( end( $keys ) === $step ) {
			return admin_url();
		}

		$step_index = array_search( $step, $keys, true );
		if ( false === $step_index ) {
			return '';
		}

		return add_query_arg( 'step', $keys[ $step_index + 1 ], remove_query_arg( 'activate_error' ) );
	}

	/**
	 * Kurulum Sihirbazı Başlığı.
	 */
	public function setup_wizard_header() {
		$wp_version_class = 'branch-' . str_replace( array( '.', ',' ), '-', floatval( get_bloginfo( 'version' ) ) );

		set_current_screen();
		?>
		<!DOCTYPE html>
		<html <?php language_attributes(); ?>>
		<head>
			<meta name="viewport" content="width=device-width" />
			<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
			<title><?php esc_html_e( 'Entego WooCoomerce &rsaquo; N11 Eklentisi Yükleme', 'entego-n11' ); ?></title>
			<?php do_action( 'admin_enqueue_scripts' ); ?>
			<?php wp_print_scripts( 'entego-n11-setup' ); ?>
			<?php do_action( 'admin_print_styles' ); ?>
			<?php do_action( 'admin_head' ); ?>
		</head>
		<body class="wc-setup wp-core-ui <?php echo esc_attr( 'wc-setup-step__' . $this->step ); ?> <?php echo esc_attr( $wp_version_class ); ?>">
		<h1 class="wc-logo"><a target="_blank" href="https://entego.com.tr/"><img src="<?php echo esc_url( ENTN11()->plugin_url() ); ?>/admin/img/entego_logo.svg" alt="<?php esc_attr_e( 'Entego WooCommerce N11 Eklentisi', 'entego-n11' ); ?>" /></a></h1>
		<?php
	}

	/**
	 * Kurulum Sihirbazı Altbilgisi.
	 */
	public function setup_wizard_footer() {
		?>
			<?php if ( 'n11_anahtarlar' === $this->step ) : ?>
				<a class="wc-setup-footer-links" href="<?php echo esc_url( admin_url() ); ?>"><?php esc_html_e( 'Şimdilik geç', 'entego-n11' ); ?></a>
			<?php elseif ( 'kategori_secimi' === $this->step || 'urun_gonder' === $this->step ) : ?>
				<a class="wc-setup-footer-links" href="<?php echo esc_url( $this->get_next_step_link() ); ?>"><?php esc_html_e( 'Bu Adımı Atla', 'entego-n11' ); ?></a>
			<?php endif; ?>
			</body>
		</html>
		<?php
	}

	/**
	 * Adımların çıktısını alın.
	 */
	public function setup_wizard_steps() {
		$output_steps      = $this->steps;


		unset( $output_steps['karsilama'] );

		?>
		<ol class="wc-setup-steps">
			<?php
			foreach ( $output_steps as $step_key => $step ) {
				$is_completed = array_search( $this->step, array_keys( $this->steps ), true ) > array_search( $step_key, array_keys( $this->steps ), true );

				if ( $step_key === $this->step ) {
					?>
					<li class="active"><?php echo esc_html( $step['name'] ); ?></li>
					<?php
				} elseif ( $is_completed ) {
					?>
					<li class="done">
						<a href="<?php echo esc_url( add_query_arg( 'step', $step_key, remove_query_arg( 'activate_error' ) ) ); ?>"><?php echo esc_html( $step['name'] ); ?></a>
					</li>
					<?php
				} else {
					?>
					<li><?php echo esc_html( $step['name'] ); ?></li>
					<?php
				}
			}
			?>
		</ol>
		<?php
	}

	/**
	 * Content Steplerin yüklendiği sayfa
	 */
	public function setup_wizard_content() {
		echo '<div class="wc-setup-content">';
		if ( ! empty( $this->steps[ $this->step ]['view'] ) ) {
			call_user_func( $this->steps[ $this->step ]['view'], $this );
		}
		echo '<div class="creator">';
		echo '	<span class="creatorText" >'.esc_html('Bu Eklenti Fibrika Workshop Fikir İşleri Ajansı tarafından geliştirilmiştir.','entego-n11').'</span>';
		echo 	'<a class="creatorLogo" href="https://www.fibrika.com.tr" target="_blank">
					<img src="'.ENTN11()->plugin_url().'/admin/img/fibrika_logo.png" alt="Fibrika Workshop Fikir İşleri Ajansı" />
			  	</a>';
		echo '</div>';
		echo '</div>';
	}

	/**
	 * Ekran, kullanıcıların WooCommerce Admin'de yeni geliştirilmiş WooCommerce işe alım deneyimini denemelerini ister.
	 */
	public function entego_n11_setup_karsilama() {
		if(get_option('entego_n11_setup_karsilama') == 'yes'){
			wp_safe_redirect( esc_url_raw( $this->get_next_step_link() ) );
		}
		?>
			<div class="wc-setup-step__karsilama-wrapper">
				<p class="wc-setup-step__karsilama-welcome"><?php esc_html_e( 'Hoşgeldiniz', 'entego-n11' ); ?></p>
				<h1 class="wc-logo"><a href="https://entego.com.tr/"><img src="<?php echo esc_url( ENTN11()->plugin_url() ); ?>/admin/img/entego_logo.svg" alt="<?php esc_attr_e( 'Entego WooCommerce N11 Eklentisi', 'entego-n11' ); ?>" /></a></h1>
				<p><?php esc_html_e( 'Entego WooCoomerce N11 Eklentisini kurduğunuz için teşekkür ederiz. Amacımız sizlerin ürün gönderiminde ve mağazalarınızı yönetmenizi kolaylaştırmak, eklenti kurulumuna devam etmek istiyormusunuz ?', 'entego-n11' ); ?></p>

				<form method="post" class="activate-new-onboarding">
					<?php wp_nonce_field( 'entego-n11-setup' ); ?>
					<p class="wc-setup-actions step">
						<button class="button-primary button button-large" value="<?php esc_attr_e( '', 'entego-n11' ); ?>" name="save_step"><?php esc_html_e( 'Evet, lütfen', 'entego-n11' ); ?></button>
					</p>
					<input type="hidden" name="save_step" value="karsilama" />
				</form>

				<p class="wc-setup-step__karsilama-plugin-info"><?php esc_html_e( 'Bu adımdan sonra N11 tarafından size verilen bilgileri girmeniz gerekiyor.', 'entego-n11' ); ?></p>
			</div>
		<?php
	}

	/**
	 * WooCommerce yöneticisini kurar ve yeni işe alım deneyimine yönlendirir.
	 */
	public function entego_n11_setup_karsilama_save() {
		check_admin_referer( 'entego-n11-setup' );

		update_option( 'entego_n11_setup_karsilama', 'yes' );

		wp_safe_redirect( esc_url_raw( $this->get_next_step_link() ) );
		exit;
	}

	/**
	 * Api Anahtarları Kayıt Sayfası
	 * 
	 */
	public function entego_n11_setup_anahtarlar() {
		$key        = get_option('entego_n11_api_key');
		$key2      = get_option('entego_n11_api_secret_key');
		if(isset($_GET['activate_error'])){

			$error_message = $this->get_activate_error_message( sanitize_text_field( wp_unslash( $_GET['activate_error'] ) ) );
			$description = $error_message;
			echo '<p style="color:red">'.sanitize_text_field($_GET['mesaj']).'</p>';
		}
		?>
		<form method="post" class="address-step">
			<input type="hidden" name="save_step" value="n11_anahtarlar" />
			<?php wp_nonce_field( 'entego-n11-setup' ); ?>
			<p class="store-setup"><?php esc_html_e( 'N11 tarafından Mağaza yönetim panelinde size verilen api ve api secret keylerini girmelisiniz. Nerede olduğunu bilmiyorsanız aşşağıdaki linke tıklayınız.', 'entego-n11' ); ?></p>
			<a href="#" class="nasil-yapilir"><?php esc_html_e("Api Anahtarların nasıl alındığını bilmiyorsanız tıklayın.","entego-n11") ?></a>
			<div class="store-address-container">

				<label class="location-prompt" for="api_key"><?php esc_html_e( 'N11 Api Anahtarı', 'entego-n11' ); ?></label>
				<input type="text" id="api_key" class="location-input" name="api_key" required value="<?php echo esc_attr( $key ); ?>" />

				<label class="location-prompt" for="api_secret_key"><?php esc_html_e( 'N11 Api Secret Anahtarı', 'entego-n11' ); ?></label>
				<input type="text" id="api_secret_key" class="location-input" name="api_secret_key" value="<?php echo esc_attr( $key2 ); ?>" />
			</div>

			<?php $this->tracking_modal(); ?>

			<p class="wc-setup-actions step">
				<button class="button-primary button button-large" type="submit" value="<?php esc_attr_e( "Kontrol Et", 'entego-n11' ); ?>" name="save_step"><?php esc_html_e( "Kontrol Et", 'entego-n11' ); ?></button>
			</p>
		</form>
		<?php
	}

	/**
	 * Api Key Tarif Modalı
	 */
	public function tracking_modal() {
		?>
		<script type="text/template" id="tmpl-wc-modal-tracking-setup">
			<div class="wc-backbone-modal woocommerce-tracker">
				<div class="wc-backbone-modal-content">
					<section class="wc-backbone-modal-main" role="main">
						<header class="wc-backbone-modal-header">
							<h1><?php esc_html_e( 'N11 Api Keylerin Yerlerini Öğrenme', 'entego-n11' ); ?></h1>
						</header>
						<article>
							<img src="<?=ENTN11()->plugin_url()?>/admin/img/tarifler/tarif1.jpg" alt="">
							<img src="<?=ENTN11()->plugin_url()?>/admin/img/tarifler/tarif2.jpg" alt="">
							<img src="<?=ENTN11()->plugin_url()?>/admin/img/tarifler/tarif3.jpg" alt="">
						</article>
						<footer>
							<div class="inner">
								<button class="button button-primary button-large modal_kapat" id="modal_kapat" aria-label="<?php esc_attr_e( 'Kapat', 'entego-n11' ); ?>"><?php esc_html_e( 'Kapat', 'entego-n11' ); ?></button>
							</div>
						</footer>
					</section>
				</div>
			</div>
			<div class="wc-backbone-modal-backdrop modal-close"></div>
		</script>
		<?php
	}

	/**
	 * Api Anahtaları kayıt Fonksiyonu
	 */
	public function entego_n11_setup_anahtarlar_save() {
		check_admin_referer( 'entego-n11-setup' );

		$key        = isset( $_POST['api_key']) ? wc_clean( wp_unslash( sanitize_text_field($_POST['api_key']) ) ) : '';
		$key2      = isset( $_POST['api_secret_key'] ) ? wc_clean( wp_unslash( sanitize_text_field($_POST['api_secret_key']) ) ) : '';
		update_option('entego_n11_api_key',$key);
		update_option('entego_n11_api_secret_key',$key2);
		$response = Entego_N11_Baglanti::HTTPPost("yeniKayit", array(
			'api_key' => $key,
			'api_secret_key' => $key2,
			'alan_adi'	=> get_site_url(),
		));
		$response = json_decode($response);
		if(!$response->sonuc){

			update_option('entego_n11_aktif',false);

			$redirect_url = esc_url_raw( add_query_arg( array(
				'page'           => 'entego-n11-kurulum',
				'step'           => 'n11_anahtarlar',
				'activate_error' => 'hatali_api_key',
				'sonuc'			 => $response->sonuc,
				'mesaj'			 => $response->mesaj,
			), admin_url() ) );

			if($response == ''){
				$redirect_url = esc_url_raw( add_query_arg( array(
					'page'           => 'entego-n11-kurulum',
					'step'           => 'n11_anahtarlar',
					'activate_error' => 'hatali_api_key',
					'mesaj'			 => esc_html('Entego İle bağlantı sağlanamadı.','entego-n11'),
				), admin_url() ) );
			}
			wp_safe_redirect( $redirect_url );

		}else{

			update_option('entego_n11_aktif',true);
			update_option('entego_n11_key',$response->entego_api);
			wp_safe_redirect( esc_url_raw( $this->get_next_step_link() ) );
			
		}
		exit;
	}

	/**
	 * Kategori Eşleştirme Alanı.
	 */
	public function entego_n11_setup_kategori() {
		if(!entego_n11_calisma_kontrol()){
			wp_safe_redirect( esc_url_raw( admin_url( 'admin.php?page=entego-n11-kurulum&step=n11_anahtarlar' ) ) );
		}
		global $wpdb;
		?>
		<style>
			.form-field .select2{
				margin-top:10px;
				margin-bottom:15px;
				width:100%;
			}
			.form-field {
				width:60%;
			}
			.kutular{
				display:flex;
  				flex-wrap: wrap;
				justify-content:center;
			}
			.is-active {
				visibility:visible;
			}
		</style>
		<h1><?php esc_html_e( 'Kategori Eşleştirme', 'entego-n11' ); ?></h1>
		<p>
			Ürünlerinizi senkronize bir şekilde n11'e gönderebilmek için WooCoomerce üzerinde kategorilerinizin karşılığını n11 kategorileri arasında seçip kaydetmelisiniz. Kategorisini eşleştirmediğiniz ürünlerinizi n11'e gönderemezsiniz.
		</p>
		<form method="post">
			<div class="kutular">
				<div class="form-field form-required term-name-wrap">
					<label style="margin-bottom:15px;" for="wooKategori">WooCommerce Kategorisi Seçiniz.</label><br>
						<?php
						$taxonomies = get_terms( array(
							'taxonomy' => 'product_cat',
							'hide_empty' => false
						) );
						
						if ( !empty($taxonomies) ) :
							$output = '<select id="wooKategori" name="wooKategori" class="location-input wc-enhanced-select dropdown postform" required>';
							
							$output.= '<option value="" >Seçim Yapınız</option>';
							foreach( $taxonomies as $category ) {
								$termId = $category->term_id;
								$katTabName = $wpdb->prefix.'entego_n11_kategoriler';
								$kontrol = $wpdb->get_results("SELECT * FROM $katTabName WHERE woocommerce_kategori_id = '$termId'");
								if($wpdb->num_rows < 1){
									$output.= '<option style="font-weight:bold;" value="'.esc_attr($category->name.'-'.$category->term_id).'">'. esc_html( $category->name ) .'</option>';
								}
							}
							$output.='</select>';
							echo $output;
						endif;
					?>
				</div>
				<?php

					$key        = get_option('entego_n11_api_key');
					$key2      = get_option('entego_n11_api_secret_key');
					$entego_key = get_option('entego_n11_key');
					$response = Entego_N11_Baglanti::HTTPPost("anaKategoriGonder", array(
						'api_key' => $key,
						'api_secret_key' => $key2,
						'alan_adi'	=> get_site_url(),
						'entego_key' => $entego_key
					));
					$response = json_decode($response);
					if($response == ''){
						echo '<p style="color:red" >'.esc_html_e('Entego\'ya bağlantı sağlanamadı, lütfen daha sonra tekrar deneyiniz.','entego-n11').'</p>';
					}elseif(!$response->sonuc) {
						echo '<p style="color:red">'.$response->mesaj.'</p>';
					}else {
				?>
					<div class="form-field form-required term-name-wrap">
						<label for="n11_1">N11 1. Grup Kategori</label><br>
						<select style="width:100%" id="n11_1" name="n11_1" class="location-input wc-enhanced-select dropdown postform" required>
							<option value="">Seçimi Yap</option>
							<?php
							$toplam = count($response->kategoriler);
							for ($i=0; $i < $toplam; $i++) { ?>
								<option value="<?=$response->kategoriler[$i]->id.'-'.$response->kategoriler[$i]->name;?>"><?=$response->kategoriler[$i]->name;?></option>
							<?php } ?>
						</select>
					</div>

					<div class="form-field form-required term-name-wrap">
						<label for="n11_2">N11 2. Grup Kategori</label><br>
						<select style="width:100%" id="n11_2" name="n11_2" class="location-input wc-enhanced-select dropdown postform" required>
							<option value="0">Varsayılan</option>
						</select>
					</div>

					<div class="form-field form-required term-name-wrap">
						<label for="n11_3">N11 3. Grup Kategori</label><br>
						<select style="width:100%" id="n11_3" name="n11_3" class="location-input wc-enhanced-select dropdown postform" required>
							<option value="0">Varsayılan</option>
						</select>
					</div>

					<div class="form-field term-display-type-wrap">
						<label for="n11_4">N11 4. Grup Kategori</label><br>
						<select style="width:100%" id="n11_4" name="n11_4" class="location-input wc-enhanced-select dropdown postform" required>
							<option value="0">Varsayılan</option>
						</select>
					</div>
				<?php
					}

				?>
				
			</div>
			<p class="wc-setup-actions step">
				
				<button class="button-primary button button-large button-ileri-kategori" value="<?php esc_attr_e( 'Devam Et', 'entego-n11' ); ?>" name="save_step"><?php esc_html_e( 'Devam Et', 'entego-n11' ); ?></button>
				<?php wp_nonce_field( 'entego-n11-setup' ); ?>
			</p>
			<p style="font-size:12px;">
				Bu kategori eşleştirmesi sadece eklentiyi siz kullanıcılarımıza tanıkmak amaçlıdır, Bundan sonraki Kategori Eşleştirmelerinizi Eklentiminizin menüsünden yapabileceksiniz.
			</p>
		</form>
		<?php
	}

	/**
	 * Kategori Aşaması Kayıt
	 */
	public function entego_n11_setup_kategori_save() {
		check_admin_referer( 'entego-n11-setup' );
			$wooKat = sanitize_text_field($_POST['wooKategori']);
			$n11_1Kat = sanitize_text_field($_POST['n11_1']);
			$n11_2Kat = sanitize_text_field($_POST['n11_2']);
			$n11_3Kat = sanitize_text_field($_POST['n11_3']);
			$n11_4Kat = sanitize_text_field($_POST['n11_4']);
			if($wooKat == '' || $n11_1Kat == ''){
				$redirect_url = esc_url_raw( add_query_arg( array(
					'page'           => 'entego-n11-kurulum',
					'step'           => 'kategori_secimi',
					'activate_error' => 'eksik_kategori_bilgisi',
				), admin_url() ) );
				wp_safe_redirect( $redirect_url );
			}else {
				$wooKat = explode("-",$wooKat);
				$wooKatAdi = $wooKat[0];
				$wooKatId = $wooKat[1];
	
				$n11kat_1 = explode("-",$n11_1Kat);
				$n11KatId_1 = $n11kat_1[0];
				$n11KatAdi_1 = $n11kat_1[1];
				
				if($n11_2Kat != 0){
					$n11kat_2 = explode("-",$n11_2Kat);
					$n11KatId_2 = $n11kat_2[0];
					$n11KatAdi_2 = $n11kat_2[1];
				}else {
					$n11KatId_2 = '0';
					$n11KatAdi_2 = '0';
				}
	
				if($n11_3Kat != 0){
					$n11kat_3 = explode("-",$n11_3Kat);
					$n11KatId_3 = $n11kat_3[0];
					$n11KatAdi_3 = $n11kat_3[1];
				}else {
					$n11KatId_3 = '0';
					$n11KatAdi_3 = '0';
				}
				
				if($n11_4Kat != 0){
					$n11kat_4 = explode("-",$n11_4Kat);
					$n11KatId_4 = $n11kat_4[0];
					$n11KatAdi_4 = $n11kat_4[1];
				}else {
					$n11KatId_4 = '0';
					$n11KatAdi_4 = '0';
				}
				
				if($n11KatId_4 != '0'){
					$n11KatId = $n11KatId_4;
					$n11Kat = $n11KatAdi_1.' > '.$n11KatAdi_2.' > '.$n11KatAdi_3.' > '.$n11KatAdi_4;
				}elseif($n11KatId_3 != '0'){
					$n11KatId = $n11KatId_3;
					$n11Kat = $n11KatAdi_1.' > '.$n11KatAdi_2.' > '.$n11KatAdi_3;
				}elseif($n11KatId_2 != '0'){
					$n11KatId = $n11KatId_2;
					$n11Kat = $n11KatAdi_1.' > '.$n11KatAdi_2;
				}
				$insert = Entego_N11_Admin::kategori_esle($wooKatId,$n11KatId,$n11Kat);
				if($insert){	
					wp_safe_redirect( esc_url_raw( $this->get_next_step_link() ) );
				}else {
					$redirect_url = esc_url_raw( add_query_arg( array(
						'page'           => 'entego-n11-kurulum',
						'step'           => 'kategori_secimi',
						'activate_error' => 'kategori_ekleme_hatasi',
					), admin_url() ) );
					wp_safe_redirect( $redirect_url );
				}
			}
		exit;
	}

	/**
	 * Helper method to retrieve the current user's email address.
	 *
	 * @return string Email address
	 */
	protected function get_current_user_email() {
		$current_user = wp_get_current_user();
		$user_email   = $current_user->user_email;

		return $user_email;
	}

	/**
	 * Kargo Teslimat Şablonu Bölümü
	 */
	public function entego_n11_setup_sablon() {
		if(!entego_n11_calisma_kontrol()){
			wp_safe_redirect( esc_url_raw( admin_url( 'admin.php?page=entego-n11-kurulum' ) ) );
		}
		?>
		<style>
		</style>
		<h1><?php esc_html_e( 'Ürün Gönderme Şablonu', 'woocommerce' ); ?></h1>
		<form method="post" class="wc-wizard-payment-gateway-form">
			<p class="ortalaContent">
				<?php
				if($_GET['activate_error'] == 'sablon_yok'){
					$error_message = $this->get_activate_error_message( sanitize_text_field( wp_unslash( $_GET['activate_error'] ) ) );
					$description = $error_message;
					echo '<p style="color:red">'.$description.'</p>';
				}
				echo '<p>';
				$link = filter_var( 'https://www.n11.com/genel/satici-yardim-ek-hizmetler-116068509',  FILTER_SANITIZE_URL );
				$format_link = '<a href="'. $link .'" target="_blank" rel="noopener">Şablon nedir ?</a>';

				printf(
					__( 'N11 entegrasyonu ile ürünlerini gönderebilmeniz için Kargo Teslimat Şablonu seçmelisiniz. %s Eğer şablonunuz yok ise n11 mağaza yönetim panelinden bir adet şablon oluşturmalısınız.  Daha sonra bu şablon değiştirilebilir.', 'entego-n11' ),
					$format_link
				);
				echo '</p>';
				echo '<p>'.esc_html('N11 Kargo teslimat süresi N11 yeni kayıt olan kullanıcılar için en az 2 gün olarak belirlenmelidir.','entego-n11').'</p>';

				$key        = get_option('entego_n11_api_key');
				$key2      = get_option('entego_n11_api_secret_key');
				$entego_key = get_option('entego_n11_key');
				$response = Entego_N11_Baglanti::HTTPPost("sablonGonder", array(
					'api_key' => $key,
					'api_secret_key' => $key2,
					'alan_adi'	=> get_site_url(),
					'entego_key' => $entego_key,
				));
				$response = json_decode($response);
				$vSablon = get_option("n11_varsayilan_sablon");
				if(!$response->sonuc){
					if($response == ''){
						$mesaj = 'Entego İle bağlantı sağlanamadı, lütfen daha sonra tekrar deneyiniz.';
					}else {
						$mesaj = $response->mesaj;
					}
					?>
					<p style="color:red;">
						<?=$mesaj?>
					</p>
					<?php
				}else {
					?>
				</p>
					<label for="teslimat_sablonu" class="location-prompt"><?php esc_html_e( 'N11 Varsayılan Ürün Gönderme Şablonu Seçiniz', 'entego-n11' ); ?> <strong>*</strong></label><br>
					<select style="width:100%" id="teslimat_sablonu" name="teslimat_sablonu" required data-placeholder="<?php esc_attr_e( 'Hangi Şablonu&hellip; kullanmak istersiniz', 'entego-n11' ); ?>" aria-label="<?php esc_attr_e( 'Kargo Teslimat Şablonu', 'entego-n11' ); ?>" class="location-input wc-enhanced-select dropdown">
						<?php
						if(count($response->sablon)<1){
						?>
							<option value="0">N11 Mağaza Panelinizden Teslimat Adresi Şablonu Oluşturmalısınız.</option>
						<?php
						}else{
						?>
							<option value="0">Lütfen Seçim Yapınız.</option>
						<?php foreach ( $response->sablon as $sablon ) : ?>
							<option <?php if($sablon->templateName == $vSablon) echo 'selected="selected"'; ?> value="<?php echo esc_attr( $sablon->templateName ); ?>"><?php echo esc_html( $sablon->templateName ); ?></option>
						<?php endforeach;
						}
						?>
					</select>
				</p>
				</p>
					<label for="teslimat_suresi" class="location-prompt"><?php esc_html_e( 'N11 Kargo Teslimat Süresi', 'entego-n11' ); ?> <strong>*</strong></label><br>
					<input style="width:100%" class="location-input" type="number" value="<?=get_option('entego_n11_kargo_suresi')?>" name="teslimat_suresi" placeholder="2" min="1" max="9">
				</p>
				<p class="wc-setup-actions step">
					<button type="submit" class="button-primary button button-large button-next" value="<?php esc_attr_e( 'Devam', 'entego-n11' ); ?>" name="save_step"><?php esc_html_e( 'Devam', 'entego-n11' ); ?></button>
				</p>
					<?php
				}
				?>
		</form>
		<?php
	}

	/**
	 * Kargo Teslimat Şablonu Bölümü Kayıt Bölümü
	 */
	public function entego_n11_setup_sablon_save() {
		if(!$_POST['teslimat_sablonu'] || !$_POST['teslimat_suresi']){
			$redirect_url = esc_url_raw( add_query_arg( array(
				'page'           => 'entego-n11-kurulum',
				'step'           => 'sablon_secimi',
				'activate_error' => 'sablon_yok',
			), admin_url() ) );
			wp_safe_redirect( $redirect_url );
		}else {
			$sablon = sanitize_text_field($_POST['teslimat_sablonu']);
			update_option("n11_varsayilan_sablon",$sablon);
			$teslimat_suresi = sanitize_text_field($_POST['teslimat_suresi']);
			update_option("entego_n11_kargo_suresi",$teslimat_suresi);
			wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
		}
		exit;
	}

	/**
	 * Önemli bilgiler adımı
	 */
	public function entego_n11_setup_bilgiler() {
		?>
		<h1><?php esc_html_e( 'Entego WooCommerce Eklentisi', 'entego-n11' ); ?></h1>
		<p>
			<?php esc_html_e( 'Eklentimizi indirdiğiniz için teşekkür ederiz. Bu Eklentiyi kullanama bilmek için bilmeniz gereken bir kaç bilgi mevcut.', 'entego-n11' ); ?>
		</p>
		<form method="post">
			<p>
				<?php 
				esc_html_e(
					'Öncelikli olarak ürünlerinizi senkronize bir şekilde n11\'e göndermek için sitenizde kayıtlı her ürününü N11 Kategorileri ile eşleştirmeniz gerekiyor.',
					'entego-n11'
				);
				?>
			</p>
			<p>
				<?php 
				esc_html_e(
					'Kategorilerinizi eşleştirdikden sonra her kategoride yer alan ürünlerin bazı özellikleri mevcut bu özelliklerden isteğe bağlı olanı ve zorunlu olan özellikleri mevcut bu zorunlu özellikleri girmediğiniz takdirde ürünleriniz eksik özellik nedeni ile gönderilemeyecektir.',
					'entego-n11'
				);
				?>
				<?php 
				esc_html_e(
					'Bu zorunlu ve isteğe bağlı özelliklerin hangileri olduğunu ve eklenmesi ürün düzenleme sayfasında sağ tarafta olan N11 Sekmesinden görüntüleyebilir ve üzerine tıkladınız takdirde seçeneklerin arasında seçerek ekleyebilirsiniz.',
					'entego-n11'
				);
				?>
			</p>
			<p>
				<?php 
				esc_html_e(
					'Hazırsanız artık ilk ürün gönderme işlemine geçebiliriz.',
					'entego-n11'
				);
				?>
			</p>
			<p class="wc-setup-actions step">
				<button type="submit" class="button-primary button button-large button-next" value="<?php esc_attr_e( 'Ürün Gönder', 'entego-n11' ); ?>" name="save_step"><?php esc_html_e( 'Ürün Gönder', 'entego-n11' ); ?></button>
				<?php wp_nonce_field( 'entego-n11-setup' ); ?>
			</p>
		</form>
		<?php
	}

	/**
	 * önemli bilgiler adımı kayıt
	 */
	public function entego_n11_setup_bilgiler_save() {
		check_admin_referer( 'entego-n11-setup' );
		wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
		exit;
	}

	protected function get_all_activate_errors() {
		return array(
			'default' => __( "Sorry! We tried, but we couldn't connect Jetpack just now 😭. Please go to the Plugins tab to connect Jetpack, so that you can finish setting up your store.", 'woocommerce' ),
			'jetpack_cant_be_installed' => __( "Sorry! We tried, but we couldn't install Jetpack for you 😭. Please go to the Plugins tab to install it, and finish setting up your store.", 'woocommerce' ),
			'register_http_request_failed' => __( "Sorry! We couldn't contact Jetpack just now 😭. Please make sure that your site is visible over the internet, and that it accepts incoming and outgoing requests via curl. You can also try to connect to Jetpack again, and if you run into any more issues, please contact support.", 'woocommerce' ),
			'siteurl_private_ip_dev' => __( "Your site might be on a private network. Jetpack can only connect to public sites. Please make sure your site is visible over the internet, and then try connecting again 🙏." , 'woocommerce' ),
			'hatali_api_key'=>__("Girmiş olduğunuz Api Anahtarı veya Api Şifre Anahtarı hatalıdır. Tekrar kontrol edip deneyiniz.","entego-n11"),
			'sablon_yok'=>__('Her hangi bir Kargo Teslimat Şablonu ve Kargo Teslimat Süresi girmelisiniz.',"entego-n11"),
			'eksik_kategori_bilgisi'=>__("Kategori seçimi yapmadınız veya eksik bir bilgi gönderdildi, tekrar deneyiniz.","entego-n11"),
			'kategori_ekleme_hatasi'=>__('Kategori Eşleştirmesi veritabanına kayıt edilirken bir hata oluştu.','entego-n11'),
		);
	}

	protected function get_activate_error_message( $code = '' ) {
		$errors = $this->get_all_activate_errors();
		return array_key_exists( $code, $errors ) ? $errors[ $code ] : $errors['default'];
	}

	/**
	 * Final step.
	 */
	public function entego_n11_setup_hazir() {
		Entego_N11::setupComplete();
		$user_email   = $this->get_current_user_email();
		$docs_url     = 'https://entego.com.tr/';
		$help_text    = sprintf(
			/* translators: %1$s: link to videos, %2$s: link to docs */
			__( 'Eklentinin nasıl kullanılacağı hakkında daha fazla bilgi ve içeriğe internet sitemizden ulaşabilirsiniz <a href="%1$s" target="_blank">Entego Entegrasyon</a>.', 'entego-n11' ),
			$docs_url
		);
		?>
		<h1><?php esc_html_e( "Artık Ürünlerinizi N11 ile Entegre Etmeye Hazırsınız!", 'entego-n11' ); ?></h1>

		<div class="woocommerce-message woocommerce-newsletter">
			<p><?php esc_html_e( "En Son gelişmelerden ve yeni eklentilerimizden haberdar olmak isterseniz E-Posta adresinizi bize gönderin.", 'entego-n11' ); ?></p>
			<form data-url="<?=get_admin_url()?>admin-ajax.php" action="<?=get_admin_url()?>admin-ajax.php" class="emailBulten" method="post" target="_blank">
				<div class="newsletter-form-container">
				<input type="hidden" value="<?=wp_create_nonce('entego_n11_mail_kayit')?>" id="nonce">
					<input
						class="newsletter-form-email"
						type="email"
						value="<?php echo esc_attr( $user_email ); ?>"
						name="email"
						placeholder="<?php esc_attr_e( 'E-Posta Adresiniz', 'entego-n11' ); ?>"
						required
					>
					<p class="wc-setup-actions step newsletter-form-button-container">
						<button
							type="submit"
							value="<?php esc_attr_e( 'Evet Lütfen!', 'entego-n11' ); ?>"
							name="subscribe"
							id="mc-embedded-subscribe"
							class="button-primary button newsletter-form-button"
						><?php esc_html_e( 'Evet Lütfen!', 'entego-n11' ); ?></button>
					</p>
				</div>
			</form>
		</div>

		<ul class="wc-wizard-next-steps">
			<li class="wc-wizard-next-step-item">
				<div class="wc-wizard-next-step-description">
					<p class="next-step-heading"><?php esc_html_e( 'Sonraki Adım', 'entego-n11' ); ?></p>
					<h3 class="next-step-description"><?php esc_html_e( 'Artık Eklentiyi Kullanmaya Hazırsınız', 'entego-n11' ); ?></h3>
					<p class="next-step-extra-info"><?php esc_html_e( "Tüm Ürünler Sayfasından Ürünlerinizi tek tek veya toplu olarak gönderebilirsiniz.", 'entego-n11' ); ?></p>
				</div>
				<div class="wc-wizard-next-step-action">
					<p class="wc-setup-actions step">
						<a class="button button-primary button-large" href="<?php echo esc_url( admin_url( 'edit.php?post_type=product' ) ); ?>">
							<?php esc_html_e( 'Tüm Ürünlere git', 'entego-n11' ); ?>
						</a>
					</p>
				</div>
			</li>
		</ul>
		<p class="next-steps-help-text"><?php echo wp_kses_post( $help_text ); ?></p>
		<?php
	}

}

new Entego_N11_Setup_Wizard();