<?php
//Bu dosya doğrudan çağrılırsa iptal edin.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Eklentinin yöneticiye özgü işlevselliği.
 *
 * @since      1.0.0
 *
 * @package    Entego_N11
 * @subpackage Entego_N11/admin
 */

/**
 * Eklentinin yöneticiye özgü işlevselliği.
 *
 * Eklenti adını, sürümünü ve nasıl yapılacağına ilişkin iki örnek kancayı tanımlar
 * yöneticiye özgü stil sayfasını ve JavaScript'i sıralayın.
 *
 * @package    Entego_N11
 * @subpackage Entego_N11/admin
 */
class Entego_N11_Admin {

	/**
	 * Bu eklentinin kimliği.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string
	 */
	private $entego_n11;

	/**
	 * Bu eklentinin sürümü.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version
	 */
	private $version;

	/**
	 * Sınıfı başlatın ve özelliklerini ayarlayın.
	 *
	 * @since    1.0.0
	 * @param      string    $entego_n11       Bu eklentinin adı.
	 * @param      string    $version    Bu eklentinin sürümü.
	 */
	public function __construct( $entego_n11, $version ) {

		$this->entego_n11 = $entego_n11;
		$this->version = $version;
		add_action('wp_loaded', array($this, "urun_row"));
		add_action('wp_ajax_entego_n11_ayarlar_kaydet_ajax',array($this,'ajax_ayarlar_kaydet'));
		add_action('wp_ajax_n11_1_kategori_ajax',array($this,'ajax_n11_kategori_ajax'));
		add_action('wp_ajax_n11_kategori_kaydet_ajax',array($this,'ajax_n11_kategori_kaydet'));
		add_action('wp_ajax_n11_kategori_sil',array($this,'ajax_n11_kategori_sil'));
		add_action( 'wp_ajax_n11_mail_abonelik_kaydi', array($this,'entego_n11_mail_kayit'));
		add_action('wp_ajax_entego_n11_wooKat_getir',array($this,'entego_n11_wooKat_getir'));
		add_action('wp_ajax_entego-n11-destek-bildirimi',array($this,'destek_bildirimi_gonder'));
		add_action('wp_ajax_entego_n11_etkisizlestirme',array($this,'eklenti_etkisizlestirme'));
		add_action('wp_ajax_entego_n11_uyelik_notu_kaldir',array($this,'uyelik_bitis_notu_kaldir'));

		add_action( 'plugin_row_meta',array($this,'kurulum_sayfasına_git'),10, 4);

		//Cron Görevleri
		add_filter('cron_schedules', array($this,'cron_gorevleri_calistir') );
		add_action( 'bl_cron_hook', array($this,'cronCalistir') );
		if ( ! wp_next_scheduled( 'bl_cron_hook' ) ) {
			wp_schedule_event( time(), 'entego_n11_cron', 'bl_cron_hook' );
		}	

	}

	/**
	 *
	 * Yönetici alanı için stil sayfalarını kaydedin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	public function enqueue_styles() {

		wp_enqueue_style( 'entego_n11_admin_style', ENTN11()->plugin_url() . '/admin/css/admin.css', array(), ENTEGO_N11_VERSION );
		wp_enqueue_style( $this->entego_n11, plugin_dir_url( __FILE__ ) . 'css/entego-n11-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Yönetici Alanı JavaScript Dosyaları Yükleme
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( 'select2-js', plugins_url('entego-n11/admin/js/admin/entego-n11-select.min.js'), array(), time() ,false);
		wp_enqueue_script( 'selectWoo-js', plugins_url('entego-n11/admin/js/admin/entego-n11-selectWoo.full.min.js'), array(), time() ,false);
		wp_enqueue_script( 'entego-n11-admin-js', plugins_url('entego-n11//admin/js/entego-n11-admin.js'),array(),time(), false );
		wp_localize_script( 'entego-n11-admin-js', 'entego_n11_ayarlar_kaydet', array(
			'ajax_url' => admin_url( 'admin-ajax.php' ),
			'nonce'    => wp_create_nonce( 'title_example' ),
			'kategori_ara_nonce'=>wp_create_nonce('entego_n11_kategori_ara'),
			'entego_n11_wooKat_getir'=>wp_create_nonce('entego_n11_wooKat_getir'),
			'entego_n11_etkisizlestirme_nonce'=>wp_create_nonce('entego_n11_etkisizlestirme_nonce'),
		) );
		wp_localize_script(
			'select2-js',
			'entego_n11_select2_lang',
			array(
				'i18n_no_matches'           => _x( 'Hiç bir sonuç bulunamadı', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_ajax_error'           => _x( 'Yüklenirken bir sorun oluştu.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_short_1'    => _x( 'En az 1 karakter girmelisiniz.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_short_n'    => _x( 'Lütfen en az %qty% karakter yazınız', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_long_1'     => _x( 'Çok fazla karakter var 1 karakter silmelisiniz.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_input_too_long_n'     => _x( 'PLütfen en az %qty% karakter siliniz', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_selection_too_long_1' => _x( 'Bir seçim yapmalısınız', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_selection_too_long_n' => _x( 'En az %qty% seçim yapabilirsiniz.', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_load_more'            => _x( 'Sonuçlar yükleniyor&hellip;', 'gelişmiş seçim', 'entego-n11' ),
				'i18n_searching'            => _x( 'Aranıyor', 'gelişmiş seçim', 'entego-n11' ),
				'ajax_url'                  => admin_url( 'admin-ajax.php' ),
				'search_products_nonce'     => wp_create_nonce( 'search-products' ),
				'search_customers_nonce'    => wp_create_nonce( 'search-customers' ),
			)
		);
	}

	/**
	 *
	 * APi Key ve APİ SECRET Key Kontrolü
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	public function api_kontrol($sonuc = false){
		$aktif 		= get_option('entego_n11_aktif');
		if($aktif != 1){
			return false;
		}else {
			return true;
		}
	}

	/**
	 *
	 * Ürünler sayfası Ürün Gönder Butonu
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	public function urun_row(){
		if(!defined('WPFC_HIDE_CLEAR_CACHE_BUTTON') || (defined('WPFC_HIDE_CLEAR_CACHE_BUTTON') && !WPFC_HIDE_CLEAR_CACHE_BUTTON)){
			if($this->api_kontrol(true)){
				include_once plugin_dir_path(__FILE__)."partials/entego-n11-admin-column.php";

				$column = new Entego_N11_Urun_Ekle_Row();
				$column->add();
			}
		}
	}

	/**
	 * Yönetici Sayfası Siparişler Sayfasu
	 *
	 * @since    1.0.0
	 */
	public function siparisler_page(){
		$n11 = $this->api_kontrol();
		require 'partials/entego-n11-admin-siparisler.php';
	}

	/**
	 * Yönetici Sayfası Kategoriler
	 *
	 * @since    1.0.0
	 */
	public function kategoriler(){
		$n11 = $this->api_kontrol();
		echo '<h1>Kategoriler</h1>';
		if($_POST['action'] == 'delete' || $_POST['action2'] == 'delete'){
            $ids = $_POST['delete_tags']; // This data is an array and the sequence is checked and checked in the loop.
            if(is_array($ids)){
                $this->topluKategoriSil($ids);
            }
		}
		require 'partials/entego-n11-admin-kategoriler.php';
	}

	/**
	 * Sonuçlar Sayfası
	 *
	 * @since    1.0.0
	 */
	public function urunSonuclar(){
		$this->api_kontrol();
		
		if($_GET['action'] == -1){unset($_REQUEST['action']);}else {$action = sanitize_text_field($_GET['action']);}
		if($_GET['action2'] == -1){unset($_REQUEST['action2']);}else {$action = sanitize_text_field($_GET['action2']);}
		if($action){
			if($action === 'sil'){
                if(is_array($_GET['hata_id'])){ // This data is an array and the sequence is checked and checked in the loop.
                    foreach($_GET['hata_id'] as $ht){
                        Entego_N11_Urun_Ekle_Row::hata_sil(sanitize_text_field($ht));
                    }
                    $hata = array(
                        'mesaj' =>esc_html('Seçmiş olduğunuz hatalar başarıyla silindi','entego-n11'),
                        'sayi'	=> count($_GET['hata_id']),
                    );
                }
			}elseif($action === 'tekrar'){
                if(is_array($_GET['hata_id'])){ // This data is an array and the sequence is checked and checked in the loop.
                    global $wpdb;
                    $tabloAdi = $wpdb->prefix.'entego_n11_hatalar';
                    foreach($_GET['hata_id'] as $dt){
                        $dt = sanitize_text_field($dt);
                        $result = $wpdb->get_row("SELECT * FROM $tabloAdi WHERE id = $dt LIMIT 1");
                        Entego_N11_Urun_Ekle_Row::hata_sil($dt);
                        Entego_N11_Urun_Ekle_Row::cronUrunEkle($result->post_id);
                    }
                    $hata = array(
                        'mesaj' =>esc_html('Seçmiş olduğunuz ürünler tekrar sıraya alındı.','entego-n11'),
                        'sayi'	=> count($_GET['hata_id']),
                    );
                }
            }
            unset($_GET['hata_id']);
            unset($_GET['action']);
            unset($_GET['action2']);

            $adminUrl = admin_url('admin.php?');
            foreach($_GET as $key => $get){
                $key = sanitize_text_field($key);
                $get = sanitize_text_field($get);
                $adminUrl.=$key.'='.$get.'&';
            }
        }
        
		require 'partials/entego-n11-admin-sonuclar.php';
	}

	/**
	 * Yönetici Sayfası Ayarlar
	 *
	 * @since    1.0.0
	 */
	public function ayarlar(){
		$this->api_kontrol();
		echo '<h1>'.esc_html('Ayarları Düzenle','entego-n11').'</h1>';
		require 'partials/entego-n11-admin-ayarlar.php';
    }
    

	/**
	 * Ayarlar Sayfası AJAX
	 *
	 * @since    1.0.0
	 */
	public function ajax_ayarlar_kaydet(){
		$api 		= sanitize_text_field($_POST['api']);
		$api_secret	= sanitize_text_field($_POST['api_secret']);
		$api_sablon	= sanitize_text_field($_POST['api_sablon']);
		$tes_suresi	= sanitize_text_field($_POST['tes_suresi']);
		$autosave	= sanitize_text_field($_POST['autosave']);

		if($api == '' || $api_secret == ''){
			wp_send_json(array(
				'sonuc'=>'eror',
				'mesaj'=>esc_html('Eksik Alan Bırakmamalısınız.','entego-n11')
			));
		}else {


			$option = 'n11_varsayilan_sablon';
			update_option($option,$api_sablon);
			$option = 'entego_n11_kargo_suresi';
			update_option($option,$tes_suresi);
			if(isset($autosave)){
				$option = 'entego_n11_autosave';
				update_option($option,$autosave);
			}
			$option = 'entego_n11_api_key';
			update_option($option,$api);
			$option = 'entego_n11_api_secret_key';
			update_option($option,$api_secret);

			$key        	= $api;
			$key2      		= $api_secret;

			$yeniKayit = Entego_N11_Baglanti::HTTPPost("yeniKayit", array(
				'api_key' => $key,
				'api_secret_key' => $key2,
                'alan_adi'	=> get_site_url(),
                'ip'=>$_SERVER['SERVER_ADDR'],
			));
			$reSonuc = json_decode($yeniKayit);
			if($reSonuc == ''){
				wp_send_json(array(
					'sonuc'=>false,
					'mesaj'=>esc_html('Entego\'ya ulaşılamıyor, lütfen daha sonra tekrar deneyiniz.','entego-n11'),
				));
			}elseif(!$reSonuc->sonuc){
				delete_option('entego_n11_aktif');
				wp_send_json(array(
					'sonuc'=>false,
					'mesaj'=>$reSonuc->mesaj,
				));
			}else {
				update_option('entego_n11_aktif',true);
				update_option('entego_n11_key',$reSonuc->entego_api);
				wp_send_json(array(
					'sonuc'=>true,
					'mesaj'=>esc_html('Başarıyla kayıt edildi','entego-n11'),
					'sablon'=>$reSonuc->request,
					'sablonSelect'=>get_option('n11_varsayilan_sablon',true),
				));
			}
		}
	}

	/**
	 * Kategoriler Sayfası 1.Kategori AJAX
	 *
	 * @since    1.0.0
	 */
	public function ajax_n11_kategori_ajax(){
		$value		= sanitize_text_field($_POST['value']);
		$nonce		= sanitize_text_field($_POST['_nonce']);
		if(!wp_verify_nonce($nonce,'title_example') || !isset($value)){
			wp_send_json(array(
				'sonuc'=>'eror',
				'mesaj'=>esc_html('Eksik Alan Bırakmamalısınız.','entego-n11')
			));
		}else {
			$key        = get_option('entego_n11_api_key');
			$key2       = get_option('entego_n11_api_secret_key');
			$entego_key = get_option('entego_n11_key');
			$response = Entego_N11_Baglanti::HTTPPost("altKategoriGonder", array(
				'api_key' => $key,
				'api_secret_key' => $key2,
				'alan_adi'	=> get_site_url(),
				'entego_key' => $entego_key,
				'kategori_id' => $value
			));
			$cevap = json_decode($response);
			if($response == ''){
				wp_send_json(array(
					'sonuc'=>'error',
					'mesaj'=>esc_html('Entego\'ya bağlantı sağlanamadı, lütfen daha sonra tekrar deneyiniz.','entego-n11'),
				));
			}elseif(!$cevap->sonuc){
				wp_send_json(array(
					'sonuc'=>'eror',
					'mesaj'=>$cevap->mesaj,
				));
			}

			wp_send_json(array(
				'sonuc'=>'ok',
				'kategoriler'=>$cevap->altKategoriler,
			));
		}
	}

	/**
	 * Kategoriler Sayfası Kategori Eşleştirme AJAX
	 *
	 * @since    1.0.0
	 */
	public function ajax_n11_kategori_kaydet(){
		$nonce 			= sanitize_text_field($_POST['_nonce']);
		$wooKat			= sanitize_text_field($_POST['wooKat']);
		$kategori_adi	= sanitize_text_field($_POST['kategori_adi']);
		$kategori_id		= sanitize_text_field($_POST['kategori_id']);
		if(!wp_verify_nonce($nonce,'title_example') || !isset($wooKat) || !isset($kategori_adi) || !isset($kategori_id)){
			wp_send_json(array(
				'sonuc'=>'eror',
				'mesaj'=>'Eksik Alan Bırakmamalısınız.'
			));
		}else {
			$insert = $this->kategori_esle($wooKat,$kategori_id,$kategori_adi);
			if($insert){
				$sonuc = array(
					'sonuc'=>'tamam',
					'mesaj'=>esc_html('Eşleştirme başarıyla kayıt edildi.','entego-n11')
				);
			}else {
				$sonuc = array(
					'sonuc'=>'eror',
					'mesaj'=>'Eşleştirme veritabanına kayıt edilirken bir hata oluştu, daha sonra tekrar deneyiniz.',
				);
			}
			wp_send_json($sonuc);
		}
	}
	
	/**
	 * Kategori eşleştirme sayfası Kategori eşleştirmesi Silme
	 *
	 * @since    1.0.0
	 */
	public function ajax_n11_kategori_sil(){
		$value 		= sanitize_text_field($_POST['value']);
		$nonce		= sanitize_text_field($_POST['_nonce']);
		if(!wp_verify_nonce($nonce,'title_example') || !isset($value)){
			wp_send_json(array(
				'sonuc'=>'eror',
				'mesaj'=>esc_html('Eksik bilgi bulunmaktadır. Sayfayı yenileyip tekrar deneyiniz.','entego-n11')
			));
		}else {
			$kategori = get_term($value);
			$args = array(
				'category' => array($kategori->slug),
				'limit'	=> -1
			);
			$products = wc_get_products( $args );
			foreach($products as $urun){
				delete_post_meta($urun->id,'n11Kategori_id');
				delete_post_meta($urun->id,'n11Kategori_adi');
			}
			global $wpdb;
			$tablo_adi = $wpdb->prefix.'entego_n11_kategoriler';
			$delete = $wpdb->delete($tablo_adi, array('woocommerce_kategori_id'=>$value));
			if($delete){
				$sonuc = array(
					'sonuc'=>'tamam',
					'mesaj'=>esc_html('Eşleştirme başarıyla silindi.','entego-n11')
				);
			}else {
				$sonuc = array(
					'sonuc'=>'eror',
					'mesaj'=>esc_html('Eşleştirme veritabanından silinirken bir hata oluştu, daha sonra tekrar deneyiniz.','entego-n11')
				);
			}
			wp_send_json($sonuc);
		}
	}

	
	/**
	 * Toplu olarak kategoril Silme İşlemi
	 *
	 * @since    1.0.0
	 */
	public function topluKategoriSil($idler){
		if(is_array($idler)){
			global $wpdb;
			$tablo_adi = $wpdb->prefix.'entego_n11_kategoriler';
			foreach($idler as $val){
				$val = sanitize_text_field($val);
				$kategori = get_term($val);
				$args = array(
					'category' => array($kategori->slug),
					'limit'	=> -1
				);
				$products = wc_get_products( $args );
				foreach($products as $urun){
					delete_post_meta($urun->id,'n11Kategori_id');
					delete_post_meta($urun->id,'n11Kategori_adi');
				}
				$delete = $wpdb->delete($tablo_adi, array('woocommerce_kategori_id'=>$val));
				if(!$delete){$hata = 1;}
			}
			if($hata){
				echo '<div class="notice notice-error ">
				<p>'.esc_html('Bilinmeyen bir hata oluştu.','entego-n11').'</p>
				</div>';
			}else {
			echo '<div class="notice notice-success ">
				<p>'.esc_html('Seçmiş olduğunuz kategori eşleştirmeleri başarıyla silindi.','entego-n11').'</p>
				</div>';
			}
			
		}else {
			echo '<div class="notice notice-info ">
				<p>'.esc_html('Hiç seçim yapmadınız.','entego-n11').'</p>
				</div>';
		}
			
	}

	/**
	 * Kategori Eşleme
	 *
	 * @since    1.0.0
	 */
	public function kategori_esle($wKat_id,$n11Kat_id,$n11Kat){
		global $wpdb;
		$tablo_adi = $wpdb->prefix.'entego_n11_kategoriler';

		$kategori = get_term($wKat_id);
		$args = array(
			'category' => array($kategori->slug),
			'limit'	=> -1
		);
		$products = wc_get_products( $args );
		$sonc = [];
		foreach($products as $urun){
			$up1 =update_post_meta($urun->id,'n11Kategori_id',$n11Kat_id);
			$up2 =update_post_meta($urun->id,'n11Kategori_adi',$n11Kat);
		}
		$data = array(
			'woocommerce_kategori_id'=>$wKat_id,
			'n11Kategori_id'		 =>$n11Kat_id,
			'n11Kategori'			 =>$n11Kat
		);
		$insert = $wpdb->insert($tablo_adi,$data);
		if($insert){
			return true;
		}else {
			return false;
		}
	}

	/**
	 * Kategori varlık kontrolü
	 */
	public function kategoriKontrol($kategori_id){
		global $wpdb;
		$tablo_adi = $wpdb->prefix.'entego_n11_kategoriler';
		$sorgu = $wpdb->get_results("SELECT woocommerce_kategori_id FROM $tablo_adi WHERE woocommerce_kategori_id = $kategori_id");
		if($wpdb->num_rows>0){
			return true;
		}else {
			return false;
		}

	}

	public function kurulum_sayfasına_git( $links_array, $plugin_file_name, $plugin_data, $status ) {
		if( strpos( $plugin_file_name, basename(__FILE__) )) {
			$links_array[] = '<a href="'.admin_url().'">Kurulum Sayfası</a>';
		}
	 
		return $links_array;
	
	}

	/** 
	 * Cron GÖrevi
	 * 
	 */
	public function cron_gorevleri_calistir($schedules){
		$schedules['entego_n11_cron'] = array(
			'interval' => 60*1,
			'display'  => esc_html__( 'Sırada bekleyen ürünleri gönderme' ),
		);
	 
		return $schedules;
	}
	
	public function cronCalistir(){
		$entego = new Entego_N11_Urun_Ekle_Row();
		$entego->urunKontrol();
	}

	public function entego_n11_mail_kayit(){
		$gizliAnahtar		= sanitize_text_field($_POST['gizliAnahtar']);
		$mail				= sanitize_text_field($_POST['mail']);
		if(!wp_verify_nonce($gizliAnahtar,'entego_n11_mail_kayit') || !isset($gizliAnahtar) || !isset($mail)){
			wp_send_json([
				'sonuc'=>false,
				'mesaj'=>esc_html('Doğrulama hatası, sayfayı yenileyip tekrar deneyiniz.','entego-n11'),
			]);
		}else {
			$entego_key = get_option('entego_n11_key');
			$response = Entego_N11_Baglanti::HTTPPost("mail-kayit", array(
				'mail'=>$mail,
				'entego_key' => $entego_key,
				'alan_adi'	=> get_site_url(),
			));
			$cevap = json_decode($response);
			if($response == ''){
				wp_send_json([
					'sonuc'=>false,
					'cevap'=>esc_html('Entego API ile şuanda bağlantı sağlanamıyor, lütfen daha sonra tekrar deneyiniz.','entego-n11'),
				]);
			}else{
                if($cevap->sonuc){
                    wp_send_json([
                            'sonuc' =>true,
                            'mesaj'=> $cevap->sonuc,
                    ]);
                }else {
                    wp_send_json([
                            'sonuc' =>false,
                            'mesaj'=> esc_html('Bilinmeyen bir hata oluştu.','entego-n11'),
                            'return'=>$response
                    ]);
                }
			}
		}
	}
	
	public function entego_n11_wooKat_getir(){
		$nonce = sanitize_text_field($_POST['nonce']);
		$kategori_id = sanitize_text_field($_POST['kategori_id']);
		if(!wp_verify_nonce($nonce,'entego_n11_wooKat_getir') || !isset($kategori_id)){
			wp_send_json([
				'sonuc'=>false,
				'mesaj'=>'Eksik veriler oluştuğu için bağlantı reddedildi, lütfen sayfayı yenileyip tekrar deneyiniz.'
			]);
		}else {
			$kategori = get_term($kategori_id);
			$kategori_adi = $kategori->name;

			$response = $this->kategoriSorgulama($kategori_adi);

			if(!$response['sonuc']){
				if($response['mesaj']== 'entego_key_yok'){
					wp_send_json([
						'sonuc'=>false,
						'mesaj'=>esc_html('Sistem pasif durumda ayarlar sayfasından api anahtarlarınızı kontrol ederek yeniden kaydetmelisiniz.','entego-n11'),
					]);
				}elseif($response['mesaj'] == 'entego_baglanti_yok'){
					wp_send_json([
						'sonuc'=>false,
						'mesaj'=>esc_html('Entego API ile bağlantı sağlanamadı, lütfen daha sonra tekrar deneyiniz.','entego-n11'),
					]);
				}else {
					wp_send_json([
						'sonuc'=>false,
						'mesaj'=>$response['mesaj'],
					]);
				}
			}else {
				wp_send_json($response);
			}
		}
	}

	/**
	 * Kategori Sorgulama Fonksiyonu
	 * 
	 * @since 1.0.4
	 * 
	 */
	public static function kategoriSorgulama($query){
		$key            = get_option('entego_n11_api_key');
		$key2           = get_option('entego_n11_api_secret_key');
		$entego_key     = get_option('entego_n11_key');
		$response = Entego_N11_Baglanti::HTTPPost("kategoriSorgula", array(
			'api_key' => $key,
			'api_secret_key' => $key2,
			'alan_adi'	=> get_site_url(),
			'entego_key' => $entego_key,
			'kategori'=>$query
		));
		$cevap = json_decode($response);
		if($entego_key == ''){
			return ['sonuc'=>false,'mesaj'=>'entego_key_yok'];
		}elseif(!isset($response)){
			return ['sonuc'=>false,'mesaj'=>'entego_baglanti_yok'];
		}elseif(!$cevap->sonuc){
			return ['sonuc'=>false,'mesaj'=>$cevap->sonuc];
		}else {
			$sonuc = [];
			foreach($cevap->aramaSonuc as $arama){
				$sonuc[] = [
					'id'	=> $arama->kategori_adi.'||'.$arama->kategori_id,
					'text'	=> $arama->kategori_adi,
				];
			}
			return [
				'sonuc'=>true,
				'sonuclar'=>$sonuc,
			];
		}
	}
	
	public static function ozelliklerGetir($kategori_id){
		$key            = get_option('entego_n11_api_key');
		$key2           = get_option('entego_n11_api_secret_key');
		$entego_key     = get_option('entego_n11_key');
		$response = Entego_N11_Baglanti::HTTPPost("niteliklerGonder", array(
			'api_key' => $key,
			'api_secret_key' => $key2,
			'alan_adi'	=> get_site_url(),
			'entego_key' => $entego_key,
			'kategori_id' => $kategori_id,
		));
		$cevap = json_decode($response);
		if($entego_key == ''){
			return ['sonuc'=>false,'mesaj'=>'entego_key_yok'];
		}elseif(!isset($response)){
			return ['sonuc'=>false,'mesaj'=>'entego_baglanti_yok'];
		}elseif(!$cevap->sonuc){
			return ['sonuc'=>false,'mesaj'=>$cevap->sonuc];
		}else {
			return [
				'sonuc'=>true,
				'degerler'=>$cevap->degerler,
			];
		}
	}
	
	/**
	 * Kategori Özelliklerini Gönderme 
	 */
	public static function ozelliklerDegerlerGetir($kategori_id){
		$key            = get_option('entego_n11_api_key');
		$key2           = get_option('entego_n11_api_secret_key');
		$entego_key     = get_option('entego_n11_key');
		$response = Entego_N11_Baglanti::HTTPPost("kategoriNiteliklerGonder", array(
			'api_key' => $key,
			'api_secret_key' => $key2,
			'alan_adi'	=> get_site_url(),
			'entego_key' => $entego_key,
			'kategori_id' => $kategori_id,
			'marka'=>true,
		));
		$cevap = json_decode($response);
		if($entego_key == ''){
			return ['sonuc'=>false,'mesaj'=>'entego_key_yok'];
		}elseif(!isset($response)){
			return ['sonuc'=>false,'mesaj'=>'entego_baglanti_yok'];
		}elseif(!$cevap->sonuc){
			return ['sonuc'=>false,'mesaj'=>$cevap->sonuc];
		}else {
			return [
				'sonuc'=>true,
				'degerler'=>$cevap->nitelikler,
			];
		}
	}

	/**
	 * Destek Sayfası
	 *
	 * @since    1.0.5
	 */
	public function destek_sayfasi(){
		echo '<h1>'.esc_html('Destek Talebi Gönder','entego-n11').'</h1>';
		require 'partials/entego-n11-admin-destek.php';
    }

	/**
	 * Destek Sayfası
	 *
	 * @since    1.0.5
	 */
	public function destek_bildirimi_gonder(){
		$nonce 		= sanitize_text_field($_POST['nonce']);
		$adsoyad 	= sanitize_text_field($_POST['adsoyad']);
		$email		= sanitize_text_field($_POST['email']);
		$telefon	= sanitize_text_field($_POST['telefon']);
		$mesaj		= sanitize_text_field($_POST['mesaj']);

		if(
			!wp_verify_nonce($nonce,'entego-n11-destek-bildirimi') || 
			!isset($adsoyad) || 
			!isset($email) || 
			!isset($telefon) || 
			!isset($mesaj)
		){
			wp_send_json([
				'sonuc' => false,
				'mesaj' => 'Doğrulama başarısız oldu sayfayı yenileyip tekrar deneyiniz.',
			]);
		}

		if(!filter_var($email, FILTER_VALIDATE_EMAIL)){
			wp_send_json([
				'sonuc' => false,
				'mesaj' => 'Lütfen geçerli bir eposta adresi giriniz.',
			]);
		}

		$entego_key     = get_option('entego_n11_key');
		$response = Entego_N11_Baglanti::HTTPPost("destekTalebiOlustur", array(
			'alan_adi'	=> get_site_url(),
			'entego_key' => $entego_key,
			'ad_soyad'=>$adsoyad,
			'email'=>$email,
			'telefon'=>$telefon,
			'destek_mesaj'=>$mesaj
		));
		$cevap = json_decode($response);
		wp_send_json($cevap);
	}
	


	/**
	 * Eklenti Etkisizleştirme DUrumunda
	 * Sebebini API'ye Gönderme
	 *
	 * @since    1.0.6
	 */
	public function eklenti_etkisizlestirme(){
		$nonce 		= sanitize_text_field($_POST['nonce']);
		$sebep 		= sanitize_text_field($_POST['sebep']);
		$diger_sebep= sanitize_text_field($_POST['diger_sebep']);

		if(
			!wp_verify_nonce($nonce,'entego_n11_etkisizlestirme_nonce') || 
			!isset($sebep) || ($sebep == 'diger' && $diger_sebep == '')
		){
			wp_send_json([
				'sonuc' => false,
				'mesaj' => 'Doğrulama başarısız oldu sayfayı yenileyip tekrar deneyiniz.',
			]);
		}
		if($sebep=='diger' && $diger_sebep==''){
			wp_send_json([
				'sonuc'=>false,
				'mesaj'=>'Eksik veriler oluştu, lütfen kontrol ediniz.'
			]);
		}
		$entego_key     = get_option('entego_n11_key');
		$response = Entego_N11_Baglanti::HTTPPost("etkisizlestirmeSebepKaydi", array(
			'alan_adi'	=> get_site_url(),
			'entego_key' => $entego_key,
			'sebep'=>$sebep,
			'diger_sebep'=>$diger_sebep,
		));
		$cevap = json_decode($response);
		
		wp_send_json([
			'sonuc'=>true,
		]);
	}
	
	/**
	 * Üyelik Bitiş NOtunu Kaldırma
	 * 
	 */
	public function uyelik_bitis_notu_kaldir(){
		$nonce = sanitize_text_field($_POST['nonce']);
		if(!wp_verify_nonce($nonce,'entego_n11_uyelik_notu_kaldir')){
			wp_send_json([
				'sonuc'=>false,
				'msaj'=>'Erişim Reddedildi.',
			]);
		}else {
			update_option('entego_n11_uyelik_bitis_hatirlatma',true);
			wp_send_json([
				'sonuc'=>true,
				'mesaj'=>'ok'
			]);
		}
	}
}
