<?php
//Bu dosya doğrudan çağrılırsa iptal edin.
if ( ! defined( 'WPINC' ) ) {
	die;
}
/**
 * Eklentinin yöneticiye özgü işlevselliği.
 *
 * @since      1.0.0
 *
 * @package    Entego_N11
 * @subpackage Entego_N11/admin
 */

/**
 * Eklenti Kullanma talimatları.
 *
 * Eklenti adını, sürümünü ve nasıl yapılacağına ilişkin iki örnek kancayı tanımlar
 * yöneticiye özgü stil sayfasını ve JavaScript'i sıralayın.
 *
 * @package    Entego_N11
 * @subpackage Entego_N11/admin
 */
class Entego_N11_Help {

	/**
	 * Bu eklentinin kimliği.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string
	 */
	private $entego_n11;

	/**
	 * Bu eklentinin sürümü.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version
	 */
	private $version;

	/**
	 * Sınıfı başlatın ve özelliklerini ayarlayın.
	 *
	 * @since    1.0.0
	 * @param      string    $entego_n11       Bu eklentinin adı.
	 * @param      string    $version    Bu eklentinin sürümü.
	 */
	public function __construct( $entego_n11, $version ) {

		$this->entego_n11 = $entego_n11;
		$this->version = $version;
	}



	public function get_view(){
		$tabs = apply_filters( 'entego-n11/tabs', array(
			'baslarken' => array(
				'title' => esc_html__( 'Kullanmaya Başlarken', 'entego-n11' ),
				'view'  => 'help/baslarken.php',
			),
			'api-anahtarlari'             => array(
				'title' => esc_html__( 'Api Anahtarları', 'entego-n11' ),
				'view'  => 'help/api-anahtarlar.php',
			),
			'sablon-secimi'       => array(
				'title' => esc_html__( 'Şablon seçimi ve Kargo Süresi', 'entego-n11' ),
				'view'  => 'help/sablon-secimi.php',
			),
			'kategori-eslestirme'       => array(
				'title' => esc_html__( 'Kategori Eşleştirme', 'entego-n11' ),
				'view'  => 'help/kategori-eslestirme.php',
			),
			'urun-nitelikler'       => array(
				'title' => esc_html__( 'Ürün Özellikleri', 'entego-n11' ),
				'view'  => 'help/urun-ozellikleri.php',
			),
			'urun-gonderme'       => array(
				'title' => esc_html__( 'Ürün Gönderme', 'entego-n11' ),
				'view'  => 'help/urun-gonderme.php',
			),
			'toplu-urun-gonderme'       => array(
				'title' => esc_html__( 'Toplu Ürün Gönderme', 'entego-n11' ),
				'view'  => 'help/toplu-urun-gonderme.php',
			),
		));
		?>
		<div class="wrap entego-n11-wrap">
		<span class="wp-header-end"></span>
			<h1 class="page-title"><?=esc_html_e( 'Entego WooCommerce N11 Eklentisi Kullanma Kılavuzu', 'entego-n11' )?></h1>
		 	<br>
				<div id="entego-n11-help-wrapper" class="entego-n11-tabs">
					<div class="entego-n11-tabs-navigation wp-clearfix">
						<?php foreach ( $tabs as $id => $tab ) : ?>
							<a href="#help-panel-<?=$id?>"><?=$tab['title']?></a>
						<?php endforeach;?>
					</div>
		
					<div class="entego-n11-tabs-content">
						<?php foreach ( $tabs as $id => $tab ) : ?>
							<div id="help-panel-<?=$id?>" class="entego-n11-tab">
							<?php include $tab['view']; ?>
					</div>
						<?php endforeach;?>
				</div>
		</div>
		<?php
	}

}
