<?php
/**
 *
 * Bu dosya, eklentideki eklenti bilgilerini oluşturmak için WordPress tarafından okunur
 * yönetici alanı. Bu dosya ayrıca eklenti tarafından kullanılan tüm bağımlılıkları içerir,
 * etkinleştirme ve devre dışı bırakma işlevlerini kaydeder ve bir işlevi tanımlar
 * eklentiyi başlatır.
 *
 * @link              https://entego.com.tr/
 * @since             1.0.8.1
 * @package           Entego_N11

Plugin Name: Entego N11 Entegrasyon
Plugin URI: https://entego.com.tr
Description: WooCommerce üzerinden satışını yaptığınız ürünleri bu eklenti sayesinde kolaylıkla n11.com'a gönderebileceksiniz.
Version: 1.0.8.1
Author: Fibrika Workshop
Author URI: https://fibrika.com.tr/
Text Domain: entego-n11
Domain Path: /lang


WC requires at least: 4.0
WC tested up to: 4.0

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
*/

//Bu dosya doğrudan çağrılırsa iptal edin.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Şu anda eklenti sürümü.
 */
define( 'ENTEGO_N11_VERSION', '1.0.8.1' );

if ( ! defined( 'ENTEGO_N11_PLUGIN_FILE' ) ) {
	define( 'ENTEGO_N11_PLUGIN_FILE', __FILE__ );
}

/**
 * Eklenti aktivasyon fonksiyonu
 */
if(!function_exists('active_entego_n11')){
    function activate_entego_n11() {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-entego-n11-activator.php';
        Entego_N11_Activator::activate();
    }
}

/**
 * Entego Etkisizleştirme fonksiyonu
 */
if(!function_exists('deactive_entego_n11')){
    function deactivate_entego_n11() {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-entego-n11-deactivator.php';
        Entego_N11_Deactivator::deactivate();
    }
}

register_activation_hook( __FILE__, 'activate_entego_n11' );
register_deactivation_hook( __FILE__, 'deactivate_entego_n11' );

/**
 * Uluslararasılaşmayı tanımlamak için kullanılan çekirdek eklenti sınıfı,
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-entego-n11.php';

/**
 * Eklentinin yürütülmesine başlar.
 */
if(!function_exists('run_entego_n11')){
    function run_entego_n11() {

        $plugin = new Entego_N11();
        $plugin->run();
    }
}

add_action( "admin_init", function(){
    if ( get_option( $opt_name = "entego_n11_wizard_bitirme_notu" )) {
        add_action( "admin_notices", "entego_n11_kurulum_notu_goster" );
    };
});

if(!function_exists('entego_n11_kurulum_notu_goster')){
    function entego_n11_kurulum_notu_goster() {

        ?>

        <div class="updated notice is-dismissible">
            <p><?php esc_html_e('Entego N11 Eklentisini tercih ettiğiniz için teşekkür ederiz. Eklentiyi kullanmak için kurulumu tamamlamanız gerekiyor. Eklentinin kullanımı hakkında bilgileri eklentinin menüsündeki yardım kısmından inceleyerek öğrenebilirsiniz.','entego-n11')?></p>
            <p><a href="admin.php?page=entego-n11-kurulum" class="button button-primary"><?php esc_html_e('Eklenti Kurulumu','entego-n11')?></a> <a href="javascript:window.location.reload()" class="button"><?php esc_html_e('İptal','entego-n11')?></a></p>
        </div>

        <?php

    }
}

add_action( "admin_notices", function(){
    if(!get_option('entego_n11_uyelik_bitis_hatirlatma') ){
        entego_n11_uyelik_bitis_notu(get_option('entego_n11_uyelik_bitis_tarih'), get_option('entego_n11_uyelik_kredi'));
    }
});

register_activation_hook( __FILE__, function() {
    if(get_option('entego_n11_setup_complete') != 'yes'){
        update_option( "entego_n11_wizard_bitirme_notu", 1 );
    }
});

if(!function_exists('entego_n11_uyelik_bitis_notu')){
    function entego_n11_uyelik_bitis_notu($BitisTarih = null,$kredi = null){
        if($BitisTarih){
            $bitis_tarih = date("Y-m-d",$BitisTarih);
            $bitis_tarih = new DateTime($bitis_tarih);
            $tarih = new DateTime(date("Y-m-d"));
            $interval= $tarih->diff($bitis_tarih);
            $kalanGun = (int)$interval->format("%r%a");
        }else {
            $kalanGun = 0;
        }

        if($kredi < 15 && $kalanGun <= 0 ){
            entego_n11_uyelik_krediBitmis($kredi);
        }elseif($kalanGun) {
            entego_n11_uyelik_sureBitmis($kalanGun);
        }
            
    }
}
/**
 * Kullanım Süresi Bitmiş
 *
 */
if(!function_exists('entego_n11_uyelik_sureBitmis')){
    function entego_n11_uyelik_sureBitmis($kalanGun) {
        $tip = get_option('entego_n11_deneme_uyelik');
        $p = '';
        if($kalanGun <= 3 && $kalanGun > 0){
            $gun = $kalanGun;
            $notice = 'warning';
            if($tip != ''){
                $p.=esc_html('Entego N11 WooCommerce eklentisinin deneme üyeliğini kullanmaktasınız.','entego-n11');
            }else{
                $p.=esc_html('Satın almış olduğunuz Entego N11 WooCommerce eklentisi üyeliğiniz bitmeye yaklaşmıştır.','entego-n11');
            }
            $p.='<br>';
            $p.=sprintf(
                __('Üyeliğiniz %d gün içerisinde sona erecektir. Eklentiyi kullanmaya devam edebilmeniz için üyelik satın almalısınız.','entego-n11'),
                $gun
            );
        }elseif($kalanGun<0){
            $notice = 'error';
            if($tip != ''){
                $p.= esc_html('Entego N11 WooCommerce eklentisinin deneme üyeliğini kullanmaktasınız.','entego-n11');
                $p.= '<br>';
                $p.= esc_html('Deneme Süreniz sona ermiştir, Kullanmaya devam etmek için üyelik satın almalısınız.','entego-n11');
            }else {
                $p.= esc_html('Satın almış olduğunuz Entego N11 WooCommerce eklentisinin kullanım süresi sona ermiştir.','entego-n11');
                $p.= '<br>';
                $p.= esc_html('Kullanmaya devam etmek için lütfen üyelik satın alınız.','entego-n11');
            }
        }elseif($kalanGun==0){
            $notice = 'warning';
            if($tip != ''){
                $p.= esc_html('Entego N11 WooCommerce eklentisinin deneme üyeliğini kullanmaktasınız. Bugün Deneme üyeliğiniz son günüdür. Kullanmaya devam etmek için üyelik satın almalısınız.','entego-n11');
            }else{
                $p.= esc_html('Satın almış olduğunuz Entego N11 WooCommerce eklentisi üyeliğiniz bugün bitecektir. Kullanmaya devam etmek için üyelik satın almalısınız.','entego-n11');
            }
        }else {
            return false;
        }
        entego_n11_uyelik_durumYazdir($notice,$p);
    }
}
/**
 * Kredisi Bitmiş
 *
 */
if(!function_exists('entego_n11_uyelik_krediBitmis')){
    function entego_n11_uyelik_krediBitmis($kredi) {
        $tip = get_option('entego_n11_deneme_uyelik');
        $p = '';
        if($kredi>0){
            $notice = 'warning';
            if($tip != ''){
                $p.= esc_html('Entego N11 WooCommerce eklentisinin deneme üyeliğini kullanmaktasınız.','entego-n11');
            }else{
                $p.= esc_html('Satın almış olduğunuz Entego N11 WooCommerce eklentisi krediniz azalmıştır.','entego-n11');
            }
            $p.= '<br>';
            $p.=sprintf(
                __('Eklenti Kullanım Krediniz "%d" kalmıştır. Eklentiyi kullanmaya devam edebilmeniz için üyelik satın almalısınız.','entego-n11'),
                $kredi
            );            
        }else {
            $notice = 'error';
            if($tip != ''){
                $p.= esc_html('Entego N11 WooCommerce eklentisinin deneme üyeliğini kullanmaktasınız. Kalan kullanım krediniz tükenmiştir.','entego-n11');
            }else{
                $p.= esc_html('Satın almış olduğunuz Entego N11 WooCommerce eklentisi krediniz tükenmiştir.','entego-n11');
            }
            $p.=esc_html('Kullanmaya devam etmek için eklentiyi satın almalısınız.','entego-n11');
        }
        entego_n11_uyelik_durumYazdir($notice,$p);
    }
}
/**
 * Üyelik Durumunu Ekrana Yazdırma
 *
 */
if(!function_exists('entego_n11_uyelik_durumYazdir')){
    function entego_n11_uyelik_durumYazdir($notice, $p) {
    ?>
    <div class="notice notice-<?=$notice?> is-dismissible">
        <p><?=$p?></p>
        <p><a target="_blank" href="https://entego.com.tr" class="button button-primary"><?php esc_html_e('Üyelik Satın Al','entego-n11')?></a> <a href="" id="uyelikHatirlatma" data-nonce="<?=wp_create_nonce("entego_n11_uyelik_notu_kaldir")?>" class="button"><?php esc_html_e('Hatırlatma','entego-n11')?></a></p>
    </div>
    <?php
    }
}

/**
 * Returns the main instance of WC.
 *
 * @since  2.1
 * @return WooCommerce
 */
if(!function_exists('ENTN11')){
    function ENTN11() { // phpcs:ignore WordPress.NamingConventions.ValidFunctionName.FunctionNameInvalid
        return Entego_N11::instance();
    }
}

if(!function_exists('entego_n11_calisma_kontrol')){
    function entego_n11_calisma_kontrol(){
        if(get_option('entego_n11_aktif') == true){
            return true;
        }else {
            return false;
        }
    }
}

if(!function_exists('entego_n11_textdomain')){
    function entego_n11_textdomain(){
        load_plugin_textdomain('entego-n11', FALSE, basename( dirname( __FILE__ ) ) . '/lang/' );
    }
}
//Add the filter with your plugin information
add_filter( 'plugin_action_links_' . plugin_basename( plugin_dir_path( __FILE__ ) . 'entego-n11' . '.php'), 'plugin_action_links' );
//The callback function to add the settings link
function plugin_action_links( $links ) {
  return array_merge(
    array(
      'settings' => '<a href="' . admin_url( 'admin.php?page=entego-n11-kurulum') . '">' . __( 'Kuruluma Dön', 'entego-n11' ) . '</a>'
    ),
    $links
  );
}


run_entego_n11();