<?php
//Bu dosya doğrudan çağrılırsa iptal edin.
if ( ! defined( 'WPINC' ) ) {
	die;
}
/**
 * Eklenti aktivasyonu sırasında ateşlenir
 *
 * @since      1.0.0
 *
 * @package    Entego_N11
 * @subpackage Entego_N11/includes
 */

/**
 * Eklenti aktivasyonu sırasında ateşlenir.
 *
 * Bu sınıf, eklentinin etkinleştirilmesi sırasında çalışması için gereken tüm kodu tanımlar.
 *
 * @since      1.0.0
 * @package    Entego_N11
 * @subpackage Entego_N11/includes
 */
class Entego_N11_Activator {

	/**
	 * Veritabanı Tablo Oluşturma İşlemleri
	 *
	 *
	 * @since    1.0.0
	 */
	public function activate() {
		Entego_N11_Activator::tablo_olustur_kategori();
		Entego_N11_Activator::tablo_olustur_hatalar();
		Entego_N11_Activator::tablo_olustur_cron_urunler();
		Entego_N11_Activator::eklenti_aktiflestir();
	}

	/**
	 * Veritabanı Kategori Tablosu Oluşturma İşlemleri
	 *
	 *
	 * @since    1.0.0
	 */
	public function tablo_olustur_kategori(){
		global $wpdb;

		$charset_collate = 'DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci';

		$table_name = $wpdb->prefix . "entego_n11_kategoriler";

		$sql = "CREATE TABLE $table_name (
			`id` int(11) NOT NULL AUTO_INCREMENT,
			`woocommerce_kategori_id` int(11) NOT NULL,
			`n11Kategori_id` int(11) NOT NULL,
			`n11Kategori` varchar(255) NOT NULL,
			PRIMARY KEY (`id`)
		) $charset_collate;";
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );

	}

	/**
	 * Veritabanı Hatalar Tablosu Oluşturma İşlemleri
	 *
	 *
	 * @since    1.0.0
	 * Durum : 
	 * 1 : Warning,
	 * 2 : Update-Success
	 * 
	 * Görüldü :
	 * 1 : Görülmedi,
	 * 2 : Görüldü
	 */
	public function tablo_olustur_hatalar(){
		global $wpdb;

		$charset_collate = 'DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci';
		
		$table_name = $wpdb->prefix . "entego_n11_hatalar";

		$sql = "CREATE TABLE $table_name (
			`id` INT NOT NULL AUTO_INCREMENT ,
			`post_id` INT NOT NULL ,
			`hata` VARCHAR(255) NOT NULL ,
			`hata_mesaj` VARCHAR(255) NOT NULL ,
			`olusturma_tarih` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
			`gorulme_tarih` TIMESTAMP NOT NULL ,
			`islem` VARCHAR(255) NOT NULL,
			`durum` INT NOT NULL ,
			`goruldu` INT NOT NULL ,
			PRIMARY KEY (`id`)) $charset_collate;";
		dbDelta( $sql );
	}



	/**
	 * Veritabanı Cron Ürünler Tablosu Oluşturma İşlemleri
	 *
	 *
	 * @since    1.0.0
	 * Durum : 
	 * 1 : Warning,
	 * 2 : Update-Success
	 * 
	 * Görüldü :
	 * 1 : Görülmedi,
	 * 2 : Görüldü
	 */
	public function tablo_olustur_cron_urunler(){
		global $wpdb;

		$charset_collate = 'DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci';
		
		$table_name = $wpdb->prefix . "entego_n11_cron_urunler";

		$sql = "CREATE TABLE $table_name (
			`id` INT NOT NULL AUTO_INCREMENT ,
			`urun_id` INT NOT NULL ,
			PRIMARY KEY (`id`)) $charset_collate;";
		dbDelta( $sql );
	}


	/**
	 * EKlenti aktifleşme durumunda istek atma
	 * 
	 */
	public function eklenti_aktiflestir(){
		if(get_option('entego_n11_aktiflestimi')){
			$durum = 'Eklenti yeniden aktifleşti.';
		}else {
			$durum = 'Eklenti İlk defa aktifleşti.';
			update_option('entego_n11_aktiflestimi',true);
		}
		$key        = get_option('entego_n11_api_key');
		$key2       = get_option('entego_n11_api_secret_key');
		$entego_key = get_option('entego_n11_key');
		if(!$key){
			$key = 11;
		}
		if(!$key2){
			$key = 11;
		}
		if(!$entego_key){
			$entego_key = 11;
		}

		$args = array(
            'body' => [
				'api_key' => $key,
				'api_secret_key' => $key2,
				'alan_adi'	=> get_site_url(),
				'entego_key' => $entego_key,
				'durum'=>$durum,
				'version'=>ENTEGO_N11_VERSION,
			],
            'timeout' => '120',
            'redirection' => '5',
            'httpversion' => '1.0',
            'blocking' => true,
            'headers' => array(),
            'cookies' => array()
		);

        $response = wp_remote_post('https://api.entego.com.tr/api/n11/eklentiAktiflesti', $args );
	}

}
/**
 * 
 * sablon_yok
 * alt_not_yok
 * kategori_yok
 * kategori_nitelik_eksik
 * fazla_resim
 * basarili
 * n11_hatasi
 */