<?php

//Bu dosya doğrudan çağrılırsa iptal edin.
if ( ! defined( 'WPINC' ) ) {
	die;
}
/**
 * Eklenti için tüm eylemleri ve filtreleri kaydedin.
 *
 * @since      1.0.0
 *
 * @package    Entego_n11
 * @subpackage Entego_n11/includes
 */

/**
 * Eklenti için tüm eylemleri ve filtreleri kaydedin.
 *
 * Boyunca kayıtlı tüm kancaların bir listesini tutun
 * eklentiyi ekleyin ve bunları WordPress API'sına kaydedin. Ara
 * eylemler ve filtreler listesini yürütmek için fonksiyonu çalıştırın.
 *
 * @package    Entego_n11
 * @subpackage Entego_n11/includes
 */
class Entego_N11_Loader {

	/**
	 * WordPress'e kaydedilmiş eylemler dizisi.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      array    $actions    Eklenti yüklendiğinde WordPress'e kaydedilen eylemler tetiklenir.
	 */
	protected $actions;

	/**
	 * WordPress'e kayıtlı filtre dizisi.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      array    $filters    Eklenti yüklendiğinde WordPress'e kaydedilen filtreler tetiklenir.
	 */
	protected $filters;

	/**
	 * Eylemleri ve filtreleri korumak için kullanılan koleksiyonları başlatın.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->actions = array();
		$this->filters = array();

	}

	/**
	 * WordPress'e kaydedilecek koleksiyona yeni bir eylem ekleyin.
	 *
	 * @since    1.0.0
	 * @param    string               $hook             Kaydedilmekte olan WordPress eyleminin adı.
	 * @param    object               $component        Eylemin tanımlandığı nesnenin örneğine başvuru.
	 * @param    string               $callback         $ Bileşenindeki işlev tanımının adı.
	 * @param    int                  $priority         İsteğe bağlı. İşlevin başlatılması gereken öncelik. Varsayılan 10'dur.
	 * @param    int                  $accepted_args    İsteğe bağlı. $ Callback'e iletilmesi gereken argüman sayısı. Varsayılan 1'dir.
	 */
	public function add_action( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
		$this->actions = $this->add( $this->actions, $hook, $component, $callback, $priority, $accepted_args );
	}

	/**
	 * WordPress'e kaydedilecek koleksiyona yeni bir filtre ekleyin.
	 *
	 * @since    1.0.0
	 * @param    string               $hook             Kaydedilmekte olan WordPress eyleminin adı.
	 * @param    object               $component        Eylemin tanımlandığı nesnenin örneğine başvuru.
	 * @param    string               $callback         $ Bileşenindeki işlev tanımının adı.
	 * @param    int                  $priority         İsteğe bağlı. İşlevin başlatılması gereken öncelik. Varsayılan 10'dur.
	 * @param    int                  $accepted_args    İsteğe bağlı. $ Callback'e iletilmesi gereken argüman sayısı. Varsayılan 1'dir.
	 */
	public function add_filter( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
		$this->filters = $this->add( $this->filters, $hook, $component, $callback, $priority, $accepted_args );
	}

	/**
	 * Eylemleri ve kancaları tek bir kayıtta kaydetmek için kullanılan bir yardımcı program işlevi
	 * Toplamak.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @param    array                $hooks            Kayıtlı olan kancaların toplanması (eylemler veya filtreler).
	 * @param    string               $hook             Kaydedilmekte olan WordPress filtresinin adı.
	 * @param    object               $component        Filtrenin tanımlandığı nesnenin örneğine başvuru.
	 * @param    string               $callback         $ Bileşenindeki işlev tanımının adı.
	 * @param    int                  $priority         İşlevin başlatılması gereken öncelik.
	 * @param    int                  $accepted_args    $ Callback'e iletilmesi gereken argüman sayısı.
	 * @return   array                                  WordPress'e kayıtlı eylemlerin ve filtrelerin toplanması.
	 */
	private function add( $hooks, $hook, $component, $callback, $priority, $accepted_args ) {

		$hooks[] = array(
			'hook'          => $hook,
			'component'     => $component,
			'callback'      => $callback,
			'priority'      => $priority,
			'accepted_args' => $accepted_args
		);

		return $hooks;

	}

	/**
	 * Filtreleri ve işlemleri WordPress ile kaydedin.
	 *
	 * @since    1.0.0
	 */
	public function run() {

		foreach ( $this->filters as $hook ) {
			add_filter( $hook['hook'], array( $hook['component'], $hook['callback'] ), $hook['priority'], $hook['accepted_args'] );
		}

		foreach ( $this->actions as $hook ) {
			add_action( $hook['hook'], array( $hook['component'], $hook['callback'] ), $hook['priority'], $hook['accepted_args'] );
		}

	}

}
